###################################################
### chunk number 1: foo
###################################################
options(keep.source = TRUE, width = 60)
foo <- packageDescription("gdistance")


###################################################
### chunk number 2: gdistance-1
###################################################
library(gdistance)
r <- raster(nrows=18, ncols=36) 
r <- setValues(r,runif(ncell(r), min=0.4, max=0.6))
r
tr1 <- transition(r, transitionFunction=mean, directions=8)


###################################################
### chunk number 3: gdistance-2
###################################################
tr1


###################################################
### chunk number 4: gdistance-3
###################################################
ncf <- function(x) max(x) - x[1] + x[2]
tr2 <- transition(r, ncf, 4, symm=FALSE)
class(transitionMatrix(tr1))
class(transitionMatrix(tr2))


###################################################
### chunk number 5: gdistance-4
###################################################
tr3 <- tr1*tr2
tr3 <- tr1+tr2
tr3 <- tr1*3
tr3 <- sqrt(tr1)


###################################################
### chunk number 6: gdistance-5
###################################################
tr3[cbind(1:9,1:9)] <- tr2[cbind(1:9,1:9)]
tr3[1:9,1:9] <- tr2[1:9,1:9]
tr3[1:5,1:5]


###################################################
### chunk number 7: gdistance-6 eval=FALSE
###################################################
## image(transitionMatrix(tr1))


###################################################
### chunk number 8: figure1
###################################################
print(image(transitionMatrix(tr1)))


###################################################
### chunk number 9: figure2
###################################################
plot(raster(tr1))


###################################################
### chunk number 10: gdistance-7
###################################################
tr1CorrC <- geoCorrection(tr1, type="c", multpl=FALSE)
tr2CorrC <- geoCorrection(tr2, type="c", multpl=FALSE)


###################################################
### chunk number 11: gdistance-8
###################################################
tr1CorrR <- geoCorrection(tr1, type="r", multpl=FALSE)


###################################################
### chunk number 12: gdistance-9
###################################################
tr1CorrMatrix <- geoCorrection(tr1, type="r", multpl=TRUE)
tr1CorrR <- tr1 * tr1CorrMatrix


###################################################
### chunk number 13: gdistance-10
###################################################
sP <- cbind(c(65, 5, -65), c(55, 35,-35))


###################################################
### chunk number 14: gdistance-11
###################################################
costDistance(tr1CorrC, sP)
costDistance(tr2CorrC, sP)
resistanceDistance(tr1CorrR, sP)


###################################################
### chunk number 15: gdistance-12
###################################################
origin <- SpatialPoints(cbind(105,-55))
goal <- SpatialPoints(cbind(-105,55))
rSPraster <- passage(tr1, origin, goal, theta=2)


###################################################
### chunk number 16: figure3
###################################################
plot(rSPraster)


###################################################
### chunk number 17: gdistance-13
###################################################
r1 <- passage(tr1, origin, sP[1,], theta=2)
r2 <- passage(tr1, origin, sP[2,], theta=2)
rJoint <- r1 * r2


###################################################
### chunk number 18: figure4
###################################################
plot(rJoint)


###################################################
### chunk number 19: gdistance-14
###################################################
rDiv <- max(max(r1, r2) * (1 - min(r1, r2)) - min(r1, r2), 0)


###################################################
### chunk number 20: figure5
###################################################
plot(rDiv)


###################################################
### chunk number 21: gdistance-15
###################################################
pathInc(tr1CorrC, sP[1,], sP[2:3,], type=c("divergent","joint"))


###################################################
### chunk number 22: figure6
###################################################
plot(function(x)exp(-3.5 * abs(x + 0.05)), -1, 1, xlab="slope", ylab="speed (m/s)")
lines(cbind(c(0,0),c(0,3.5)), lty="longdash")


###################################################
### chunk number 23: gdistance-16
###################################################
r <- raster(system.file("external/maungawhau.grd", package="gdistance"))


###################################################
### chunk number 24: gdistance-17
###################################################
heightDiff <- function(x){x[2] - x[1]}
hd <- transition(r,heightDiff,8,symm=FALSE)
slope <- geoCorrection(hd, scl=FALSE)


###################################################
### chunk number 25: gdistance-18
###################################################
adj <- adjacency(raster=r, fromCells = 1:ncell(r), toCells = 1:ncell(r), directions=8)
speed <- slope
speed[adj] <- exp(-3.5 * abs(slope[adj] + 0.05))


###################################################
### chunk number 26: gdistance-19
###################################################
x <- geoCorrection(speed, scl=FALSE) 


###################################################
### chunk number 27: gdistance-20
###################################################
A <- c(2667670,6479000)
B <- c(2667800,6479400)
AtoB <- shortestPath(x, A, B, output="SpatialLines")
BtoA <- shortestPath(x, B, A,  output="SpatialLines")


###################################################
### chunk number 28: fig7plot
###################################################
plot(r)
lines(AtoB, col="red", lwd=2)
lines(BtoA, col="blue")
text(A[1]-10,A[2]-10,"A")
text(B[1]+10,B[2]+10,"B")


###################################################
### chunk number 29: fig7
###################################################
plot(r)
lines(AtoB, col="red", lwd=2)
lines(BtoA, col="blue")
text(A[1]-10,A[2]-10,"A")
text(B[1]+10,B[2]+10,"B")


###################################################
### chunk number 30: gdistance-21
###################################################
Europe <- raster(system.file("external/Europe.grd", package="gdistance"))
Europe[is.na(Europe)] <- 0
data(genDist)
data(popCoord)
pC <- as.matrix(popCoord[c("x","y")])


###################################################
### chunk number 31: fig8
###################################################
plot(Europe)
text(pC[,1],pC[,2],unlist(popCoord["Population"]),cex=.7)


###################################################
### chunk number 32: gdistance-22
###################################################
geoDist <- pointDistance(pC, longlat=TRUE)
geoDist <- as.dist(geoDist)
Europe <- aggregate(Europe,3)
tr <- transition(Europe, mean, directions=8)
tr <- geoCorrection(tr, "c")
tR <- geoCorrection(tr, "r")
cosDist <- costDistance(tr,pC)
resDist <- resistanceDistance(tR,pC)
cor(genDist,geoDist)
cor(genDist,cosDist)
cor(genDist,resDist)


###################################################
### chunk number 33: gdistance-23
###################################################
origin <- unlist(popCoord[22,c("x","y")])
pI <- pathInc(tr, origin=origin, fromCoords=pC, type="joint", theta=2)
cor(genDist,pI)


